import type { SSMClient } from '@aws-sdk/client-ssm';
export declare const defaultApiEndpoint: URL;
export declare const defaultCoAPEndpoint: URL;
export type Settings = {
    apiEndpoint: URL;
    apiKey: string;
    accountDeviceClientCert: string;
    accountDevicePrivateKey: string;
    accountDeviceClientId: string;
    mqttEndpoint: string;
    mqttTopicPrefix: string;
    coapEndpoint: URL;
    coapPort: number;
};
export declare const getSettings: ({ ssm, stackName, account, }: {
    ssm: SSMClient;
    stackName: string;
    account: string;
}) => (() => Promise<Settings>);
export declare const getAPISettings: ({ ssm, stackName, account, }: {
    ssm: SSMClient;
    stackName: string;
    account: string;
}) => (() => Promise<Pick<Settings, "apiKey" | "apiEndpoint">>);
export declare const putSettings: ({ ssm, stackName, account, }: {
    ssm: SSMClient;
    stackName: string;
    account: string;
}) => ((settings: Partial<Settings>) => Promise<void>);
export declare const putSetting: ({ ssm, stackName, account, }: {
    ssm: SSMClient;
    stackName: string;
    account: string;
}) => ((property: keyof Settings, value: string, deleteBeforeUpdate: boolean) => ReturnType<({ property, value, deleteBeforeUpdate, }: {
    property: string;
    value: string;
    deleteBeforeUpdate?: boolean;
}) => Promise<{
    name: string;
}>>);
export declare const deleteSettings: ({ ssm, stackName, account, }: {
    ssm: SSMClient;
    stackName: string;
    account: string;
}) => ((property: string) => ReturnType<({ property }: {
    property: string;
}) => Promise<{
    name: string;
}>>);
export declare const validateSettings: (p: Record<string, string>) => Settings;
